@@ -16,26 +16,27 @@ class ConfirmModal extends PromiseComponent {
 
     this.handlePromise(
       this.props.executeFn(null, {
-        supressNotifications: true
+        supressNotifications: true,
       })
     ).then(this.props.close);
   }
 
   render() {
-    return <form onSubmit={this._submit} name="form">
+    return <form onSubmit={this._submit} name="form" className="modal-content">
       <ModalTitle>{this.props.title}</ModalTitle>
       <ModalBody>{this.props.message}</ModalBody>
-      <ModalSubmitFooter errorMessage={this.state.errorMessage} inProgress={this.state.inProgress} submitText={this.props.btnText || 'Confirm'} cancel={this._cancel} />
+      <ModalSubmitFooter errorMessage={this.state.errorMessage} inProgress={this.state.inProgress} submitText={this.props.btnText || 'Confirm'} cancel={this._cancel} cancelText={this.props.cancelText || 'Cancel'} />
     </form>;
   }
 }
 ConfirmModal.propTypes = {
   btnText: PropTypes.node,
   cancel: PropTypes.func.isRequired,
+  cancelText: PropTypes.node,
   close: PropTypes.func.isRequired,
   executeFn: PropTypes.func.isRequired,
   message: PropTypes.node,
-  title: PropTypes.node.isRequired
+  title: PropTypes.node.isRequired,
 };
 
 export const confirmModal = createModalLauncher(ConfirmModal);
