@@ -1,4 +1,3 @@
-// eslint-disable-next-line no-unused-vars
 import { K8sKind } from '../module/k8s';
 
 export const CatalogSourceConfigModel: K8sKind = {
@@ -7,7 +6,6 @@ export const CatalogSourceConfigModel: K8sKind = {
   labelPlural: 'CatalogSourceConfigs',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1',
-  path: 'catalogsourceconfigs',
   abbr: 'CSC',
   namespaced: true,
   crd: true,
@@ -20,7 +18,6 @@ export const OperatorSourceModel: K8sKind = {
   labelPlural: 'OperatorSource',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1',
-  path: 'operatorsources',
   abbr: 'OSRC',
   namespaced: true,
   crd: true,
@@ -33,7 +30,6 @@ export const CatalogSourceModel: K8sKind = {
   labelPlural: 'CatalogSources',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1alpha1',
-  path: 'catalogsources',
   abbr: 'CS',
   namespaced: true,
   crd: true,
@@ -46,7 +42,6 @@ export const PackageManifestModel: K8sKind = {
   labelPlural: 'PackageManifests',
   apiGroup: 'packages.operators.coreos.com',
   apiVersion: 'v1',
-  path: 'packagemanifests',
   abbr: 'PM',
   namespaced: true,
   crd: true,
@@ -59,7 +54,6 @@ export const ClusterServiceVersionModel: K8sKind = {
   labelPlural: 'ClusterServiceVersions',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1alpha1',
-  path: 'clusterserviceversions',
   abbr: 'CSV',
   namespaced: true,
   crd: true,
@@ -73,7 +67,6 @@ export const InstallPlanModel: K8sKind = {
   labelPlural: 'InstallPlans',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1alpha1',
-  path: 'installplans',
   abbr: 'IP',
   namespaced: true,
   crd: true,
@@ -86,7 +79,6 @@ export const SubscriptionModel: K8sKind = {
   labelPlural: 'Subscriptions',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1alpha1',
-  path: 'subscriptions',
   abbr: 'SUB',
   namespaced: true,
   crd: true,
@@ -99,7 +91,6 @@ export const OperatorGroupModel: K8sKind = {
   labelPlural: 'OperatorGroups',
   apiGroup: 'operators.coreos.com',
   apiVersion: 'v1',
-  path: 'operatorgroups',
   abbr: 'OG',
   namespaced: true,
   crd: true,
@@ -112,7 +103,6 @@ export const PrometheusModel: K8sKind = {
   labelPlural: 'Prometheuses',
   apiGroup: 'monitoring.coreos.com',
   apiVersion: 'v1',
-  path: 'prometheuses',
   abbr: 'PI',
   namespaced: true,
   crd: true,
@@ -126,7 +116,6 @@ export const ServiceMonitorModel: K8sKind = {
   labelPlural: 'Service Monitors',
   apiGroup: 'monitoring.coreos.com',
   apiVersion: 'v1',
-  path: 'servicemonitors',
   abbr: 'SM',
   namespaced: true,
   crd: true,
@@ -140,7 +129,6 @@ export const AlertmanagerModel: K8sKind = {
   labelPlural: 'Alertmanagers',
   apiGroup: 'monitoring.coreos.com',
   apiVersion: 'v1',
-  path: 'alertmanagers',
   abbr: 'AM',
   namespaced: true,
   crd: true,
@@ -152,8 +140,7 @@ export const ChargebackReportModel: K8sKind = {
   kind: 'Report',
   label: 'Report',
   labelPlural: 'Reports',
-  apiGroup: 'chargeback.coreos.com',
-  path: 'reports',
+  apiGroup: 'metering.openshift.io',
   apiVersion: 'v1alpha1',
   crd: true,
   plural: 'reports',
@@ -164,7 +151,6 @@ export const ChargebackReportModel: K8sKind = {
 export const ServiceModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Service',
-  path: 'services',
   plural: 'services',
   abbr: 'S',
   namespaced: true,
@@ -176,7 +162,6 @@ export const ServiceModel: K8sKind = {
 export const PodModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Pod',
-  path: 'pods',
   plural: 'pods',
   abbr: 'P',
   namespaced: true,
@@ -188,7 +173,6 @@ export const PodModel: K8sKind = {
 export const ContainerModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Container',
-  path: 'containers',
   plural: 'containers',
   abbr: 'C',
   kind: 'Container',
@@ -198,7 +182,6 @@ export const ContainerModel: K8sKind = {
 
 export const DaemonSetModel: K8sKind = {
   label: 'Daemon Set',
-  path: 'daemonsets',
   apiGroup: 'apps',
   plural: 'daemonsets',
   apiVersion: 'v1',
@@ -213,7 +196,6 @@ export const DaemonSetModel: K8sKind = {
 export const ReplicationControllerModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Replication Controller',
-  path: 'replicationcontrollers',
   plural: 'replicationcontrollers',
   abbr: 'RC',
   namespaced: true,
@@ -225,7 +207,6 @@ export const ReplicationControllerModel: K8sKind = {
 
 export const HorizontalPodAutoscalerModel: K8sKind = {
   label: 'Horizontal Pod Autoscaler',
-  path: 'horizontalpodautoscalers',
   plural: 'horizontalpodautoscalers',
   apiVersion: 'v2beta1',
   apiGroup: 'autoscaling',
@@ -239,7 +220,6 @@ export const HorizontalPodAutoscalerModel: K8sKind = {
 export const ServiceAccountModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Service Account',
-  path: 'serviceaccounts',
   plural: 'serviceaccounts',
   abbr: 'SA',
   namespaced: true,
@@ -251,7 +231,6 @@ export const ServiceAccountModel: K8sKind = {
 export const ReplicaSetModel: K8sKind = {
   label: 'Replica Set',
   apiVersion: 'v1',
-  path: 'replicasets',
   apiGroup: 'apps',
   plural: 'replicasets',
   abbr: 'RS',
@@ -265,7 +244,6 @@ export const ReplicaSetModel: K8sKind = {
 export const DeploymentModel: K8sKind = {
   label: 'Deployment',
   apiVersion: 'v1',
-  path: 'deployments',
   apiGroup: 'apps',
   plural: 'deployments',
   abbr: 'D',
@@ -279,7 +257,6 @@ export const DeploymentModel: K8sKind = {
 export const DeploymentConfigModel: K8sKind = {
   label: 'Deployment Config',
   apiVersion: 'v1',
-  path: 'deploymentconfigs',
   apiGroup: 'apps.openshift.io',
   plural: 'deploymentconfigs',
   abbr: 'DC',
@@ -293,7 +270,6 @@ export const DeploymentConfigModel: K8sKind = {
 export const BuildConfigModel: K8sKind = {
   label: 'Build Config',
   apiVersion: 'v1',
-  path: 'buildconfigs',
   apiGroup: 'build.openshift.io',
   plural: 'buildconfigs',
   abbr: 'BC',
@@ -307,7 +283,6 @@ export const BuildConfigModel: K8sKind = {
 export const BuildModel: K8sKind = {
   label: 'Build',
   apiVersion: 'v1',
-  path: 'builds',
   apiGroup: 'build.openshift.io',
   plural: 'builds',
   abbr: 'B',
@@ -318,10 +293,34 @@ export const BuildModel: K8sKind = {
   labelPlural: 'Builds',
 };
 
+export const TemplateModel: K8sKind = {
+  label: 'Template',
+  apiVersion: 'v1',
+  apiGroup: 'template.openshift.io',
+  plural: 'templates',
+  abbr: 'T',
+  namespaced: true,
+  propagationPolicy: 'Foreground',
+  kind: 'Template',
+  id: 'template',
+  labelPlural: 'Templates',
+};
+
+export const TemplateInstanceModel: K8sKind = {
+  label: 'Template Instance',
+  apiVersion: 'v1',
+  apiGroup: 'template.openshift.io',
+  plural: 'templateinstances',
+  abbr: 'TI',
+  namespaced: true,
+  kind: 'TemplateInstance',
+  id: 'templateinstance',
+  labelPlural: 'Template Instances',
+};
+
 export const ImageStreamModel: K8sKind = {
   label: 'Image Stream',
   apiVersion: 'v1',
-  path: 'imagestreams',
   apiGroup: 'image.openshift.io',
   plural: 'imagestreams',
   abbr: 'IS',
@@ -335,7 +334,6 @@ export const ImageStreamModel: K8sKind = {
 export const ImageStreamTagModel: K8sKind = {
   label: 'Image Stream Tag',
   apiVersion: 'v1',
-  path: 'imagestreamtags',
   apiGroup: 'image.openshift.io',
   plural: 'imagestreamtags',
   abbr: 'IST',
@@ -349,7 +347,6 @@ export const ImageStreamTagModel: K8sKind = {
 export const ImageStreamImportsModel: K8sKind = {
   label: 'Image Stream Import',
   apiVersion: 'v1',
-  path: 'imagestreamimports',
   apiGroup: 'image.openshift.io',
   plural: 'imagestreamimports',
   abbr: 'ISI',
@@ -362,7 +359,6 @@ export const ImageStreamImportsModel: K8sKind = {
 export const JobModel: K8sKind = {
   label: 'Job',
   apiVersion: 'v1',
-  path: 'jobs',
   apiGroup: 'batch',
   plural: 'jobs',
   abbr: 'J',
@@ -376,7 +372,6 @@ export const JobModel: K8sKind = {
 export const NodeModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Node',
-  path: 'nodes',
   plural: 'nodes',
   abbr: 'N',
   kind: 'Node',
@@ -387,7 +382,6 @@ export const NodeModel: K8sKind = {
 export const EventModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Event',
-  path: 'events',
   plural: 'events',
   abbr: 'E',
   namespaced: true,
@@ -400,7 +394,6 @@ export const ComponentStatusModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Component Status',
   labelPlural: 'Component Statuses',
-  path: 'componentstatuses',
   plural: 'componentstatuses',
   abbr: 'CS',
   kind: 'ComponentStatus',
@@ -410,7 +403,6 @@ export const ComponentStatusModel: K8sKind = {
 export const NamespaceModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Namespace',
-  path: 'namespaces',
   plural: 'namespaces',
   abbr: 'NS',
   kind: 'Namespace',
@@ -422,7 +414,6 @@ export const ProjectModel: K8sKind = {
   apiVersion: 'v1',
   apiGroup: 'project.openshift.io',
   label: 'Project',
-  path: 'projects',
   plural: 'projects',
   abbr: 'PR',
   kind: 'Project',
@@ -434,7 +425,6 @@ export const ProjectRequestModel: K8sKind = {
   apiVersion: 'v1',
   apiGroup: 'project.openshift.io',
   label: 'Project Request',
-  path: 'projectrequests',
   plural: 'projectrequests',
   abbr: '',
   kind: 'ProjectRequest',
@@ -447,7 +437,6 @@ export const IngressModel: K8sKind = {
   labelPlural: 'Ingresses',
   apiGroup: 'extensions',
   apiVersion: 'v1beta1',
-  path: 'ingresses',
   plural: 'ingresses',
   abbr: 'I',
   namespaced: true,
@@ -460,7 +449,6 @@ export const RouteModel: K8sKind = {
   labelPlural: 'Routes',
   apiGroup: 'route.openshift.io',
   apiVersion: 'v1',
-  path: 'routes',
   plural: 'routes',
   abbr: 'RT',
   namespaced: true,
@@ -471,7 +459,6 @@ export const RouteModel: K8sKind = {
 export const ConfigMapModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Config Map',
-  path: 'configmaps',
   plural: 'configmaps',
   abbr: 'CM',
   namespaced: true,
@@ -483,7 +470,6 @@ export const ConfigMapModel: K8sKind = {
 export const SecretModel: K8sKind = {
   apiVersion: 'v1',
   label: 'Secret',
-  path: 'secrets',
   plural: 'secrets',
   abbr: 'S',
   namespaced: true,
@@ -496,7 +482,6 @@ export const ClusterRoleBindingModel: K8sKind = {
   label: 'Cluster Role Binding',
   apiGroup: 'rbac.authorization.k8s.io',
   apiVersion: 'v1',
-  path: 'clusterrolebindings',
   plural: 'clusterrolebindings',
   abbr: 'CRB',
   kind: 'ClusterRoleBinding',
@@ -508,7 +493,6 @@ export const ClusterRoleModel: K8sKind = {
   label: 'Cluster Role',
   apiGroup: 'rbac.authorization.k8s.io',
   apiVersion: 'v1',
-  path: 'clusterroles',
   plural: 'clusterroles',
   abbr: 'CR',
   kind: 'ClusterRole',
@@ -520,7 +504,6 @@ export const RoleBindingModel: K8sKind = {
   label: 'Role Binding',
   apiGroup: 'rbac.authorization.k8s.io',
   apiVersion: 'v1',
-  path: 'rolebindings',
   plural: 'rolebindings',
   abbr: 'RB',
   namespaced: true,
@@ -533,7 +516,6 @@ export const RoleModel: K8sKind = {
   label: 'Role',
   apiGroup: 'rbac.authorization.k8s.io',
   apiVersion: 'v1',
-  path: 'roles',
   plural: 'roles',
   abbr: 'R',
   namespaced: true,
@@ -543,10 +525,9 @@ export const RoleModel: K8sKind = {
 };
 
 export const SelfSubjectAccessReviewModel: K8sKind = {
-  label: 'SelfSubjectAccessReview',
+  label: 'Self Subject Access Review',
   apiGroup: 'authorization.k8s.io',
   apiVersion: 'v1',
-  path: 'selfsubjectaccessreviews',
   plural: 'selfsubjectaccessreviews',
   abbr: 'SSAR',
   namespaced: true,
@@ -555,10 +536,33 @@ export const SelfSubjectAccessReviewModel: K8sKind = {
   labelPlural: 'Self Subject Access Reviews',
 };
 
+export const ResourceAccessReviewsModel: K8sKind = {
+  label: 'Resource Access Review',
+  apiGroup: 'authorization.openshift.io',
+  apiVersion: 'v1',
+  plural: 'resourceaccessreviews',
+  abbr: 'LRAR',
+  namespaced: false,
+  kind: 'ResourceAccessReview',
+  id: 'resourceaccessreview',
+  labelPlural: 'Resource Access Reviews',
+};
+
+export const LocalResourceAccessReviewsModel: K8sKind = {
+  label: 'Local Resource Access Review',
+  apiGroup: 'authorization.openshift.io',
+  apiVersion: 'v1',
+  plural: 'localresourceaccessreviews',
+  abbr: 'LRAR',
+  namespaced: true,
+  kind: 'LocalResourceAccessReview',
+  id: 'localresourceaccessreview',
+  labelPlural: 'Local Resource Access Reviews',
+};
+
 export const PersistentVolumeModel: K8sKind = {
   label: 'Persistent Volume',
   apiVersion: 'v1',
-  path: 'persistentvolumes',
   plural: 'persistentvolumes',
   abbr: 'PV',
   kind: 'PersistentVolume',
@@ -569,7 +573,6 @@ export const PersistentVolumeModel: K8sKind = {
 export const PersistentVolumeClaimModel: K8sKind = {
   label: 'Persistent Volume Claim',
   apiVersion: 'v1',
-  path: 'persistentvolumeclaims',
   plural: 'persistentvolumeclaims',
   abbr: 'PVC',
   namespaced: true,
@@ -583,7 +586,6 @@ export const PetsetModel: K8sKind = {
   label: 'Petset',
   plural: 'petsets',
   abbr: 'PS',
-  path: 'petsets',
   propagationPolicy: 'Foreground',
   kind: 'Petset',
   id: 'petset',
@@ -594,7 +596,6 @@ export const StatefulSetModel: K8sKind = {
   label: 'Stateful Set',
   apiGroup: 'apps',
   apiVersion: 'v1',
-  path: 'statefulsets',
   plural: 'statefulsets',
   abbr: 'SS',
   namespaced: true,
@@ -607,7 +608,6 @@ export const StatefulSetModel: K8sKind = {
 export const ResourceQuotaModel: K8sKind = {
   label: 'Resource Quota',
   apiVersion: 'v1',
-  path: 'resourcequotas',
   plural: 'resourcequotas',
   abbr: 'RQ',
   namespaced: true,
@@ -620,7 +620,6 @@ export const ClusterResourceQuotaModel: K8sKind = {
   label: 'Cluster Resource Quota',
   apiGroup: 'quota.openshift.io',
   apiVersion: 'v1',
-  path: 'clusterresourcequotas',
   plural: 'clusterresourcequotas',
   abbr: 'CRQ',
   namespaced: false,
@@ -635,7 +634,6 @@ export const NetworkPolicyModel: K8sKind = {
   labelPlural: 'Network Policies',
   apiVersion: 'v1',
   apiGroup: 'networking.k8s.io',
-  path: 'networkpolicies',
   plural: 'networkpolicies',
   abbr: 'NP',
   namespaced: true,
@@ -647,7 +645,6 @@ export const CustomResourceDefinitionModel: K8sKind = {
   label: 'Custom Resource Definition',
   apiGroup: 'apiextensions.k8s.io',
   apiVersion: 'v1beta1',
-  path: 'customresourcedefinitions',
   abbr: 'CRD',
   namespaced: false,
   plural: 'customresourcedefinitions',
@@ -659,7 +656,6 @@ export const CustomResourceDefinitionModel: K8sKind = {
 export const CronJobModel: K8sKind = {
   label: 'Cron Job',
   apiVersion: 'v1beta1',
-  path: 'cronjobs',
   apiGroup: 'batch',
   plural: 'cronjobs',
   abbr: 'CJ',
@@ -674,7 +670,6 @@ export const StorageClassModel: K8sKind = {
   label: 'Storage Class',
   labelPlural: 'Storage Classes',
   apiVersion: 'v1',
-  path: 'storageclasses',
   apiGroup: 'storage.k8s.io',
   plural: 'storageclasses',
   abbr: 'SC',
@@ -687,7 +682,6 @@ export const ClusterServiceBrokerModel: K8sKind = {
   label: 'Cluster Service Broker',
   labelPlural: 'Cluster Service Brokers',
   apiVersion: 'v1beta1',
-  path: 'clusterservicebrokers',
   apiGroup: 'servicecatalog.k8s.io',
   plural: 'clusterservicebrokers',
   abbr: 'CSB',
@@ -701,7 +695,6 @@ export const ClusterServiceClassModel: K8sKind = {
   label: 'Cluster Service Class',
   labelPlural: 'Cluster Service Classes',
   apiVersion: 'v1beta1',
-  path: 'clusterserviceclasses',
   apiGroup: 'servicecatalog.k8s.io',
   plural: 'clusterserviceclasses',
   abbr: 'CSC',
@@ -715,7 +708,6 @@ export const ClusterServicePlanModel: K8sKind = {
   label: 'Cluster Service Plan',
   labelPlural: 'Cluster Service Plans',
   apiVersion: 'v1beta1',
-  path: 'clusterserviceplans',
   apiGroup: 'servicecatalog.k8s.io',
   plural: 'clusterserviceplans',
   abbr: 'CSP',
@@ -729,7 +721,6 @@ export const ServiceInstanceModel: K8sKind = {
   label: 'Service Instance',
   labelPlural: 'Service Instances',
   apiVersion: 'v1beta1',
-  path: 'serviceinstances',
   apiGroup: 'servicecatalog.k8s.io',
   plural: 'serviceinstances',
   abbr: 'SI',
@@ -743,7 +734,6 @@ export const ServiceBindingModel: K8sKind = {
   label: 'Service Binding',
   labelPlural: 'Service Bindings',
   apiVersion: 'v1beta1',
-  path: 'servicebindings',
   apiGroup: 'servicecatalog.k8s.io',
   plural: 'servicebindings',
   abbr: 'SB',
@@ -756,7 +746,6 @@ export const ServiceBindingModel: K8sKind = {
 export const LimitRangeModel: K8sKind = {
   label: 'Limit Range',
   apiVersion: 'v1',
-  path: 'limitranges',
   plural: 'limitranges',
   abbr: 'LR',
   namespaced: true,
@@ -769,7 +758,6 @@ export const APIServiceModel: K8sKind = {
   label: 'API Service',
   labelPlural: 'API Services',
   apiVersion: 'v1',
-  path: 'apiservices',
   apiGroup: 'apiregistration.k8s.io',
   plural: 'apiservices',
   abbr: 'APIS',
@@ -785,7 +773,6 @@ export const MachineModel: K8sKind = {
   label: 'Machine',
   labelPlural: 'Machines',
   apiVersion: 'v1beta1',
-  path: 'machines',
   apiGroup: 'machine.openshift.io',
   plural: 'machines',
   abbr: 'M',
@@ -799,7 +786,6 @@ export const MachineSetModel: K8sKind = {
   label: 'Machine Set',
   labelPlural: 'Machine Sets',
   apiVersion: 'v1beta1',
-  path: 'machinesets',
   apiGroup: 'machine.openshift.io',
   plural: 'machinesets',
   abbr: 'MS',
@@ -813,7 +799,6 @@ export const MachineDeploymentModel: K8sKind = {
   label: 'Machine Deployment',
   labelPlural: 'Machine Deployments',
   apiVersion: 'v1beta1',
-  path: 'machinedeployments',
   apiGroup: 'machine.openshift.io',
   plural: 'machinedeployments',
   abbr: 'MD',
@@ -827,7 +812,6 @@ export const MachineConfigPoolModel: K8sKind = {
   label: 'Machine Config Pool',
   labelPlural: 'Machine Config Pools',
   apiVersion: 'v1',
-  path: 'machineconfigpools',
   apiGroup: 'machineconfiguration.openshift.io',
   plural: 'machineconfigpools',
   abbr: 'MCP',
@@ -841,7 +825,6 @@ export const MachineConfigModel: K8sKind = {
   label: 'Machine Config',
   labelPlural: 'Machine Configs',
   apiVersion: 'v1',
-  path: 'machineconfigs',
   apiGroup: 'machineconfiguration.openshift.io',
   plural: 'machineconfigs',
   abbr: 'MC',
@@ -851,12 +834,24 @@ export const MachineConfigModel: K8sKind = {
   crd: true,
 };
 
+export const MachineAutoscalerModel: K8sKind = {
+  label: 'Machine Autoscaler',
+  labelPlural: 'Machine Autoscalers',
+  apiVersion: 'v1beta1',
+  apiGroup: 'autoscaling.openshift.io',
+  plural: 'machineautoscalers',
+  abbr: 'MA',
+  namespaced: true,
+  kind: 'MachineAutoscaler',
+  id: 'machineautoscaler',
+  crd: true,
+};
+
 // Openshift cluster resources
 export const ClusterOperatorModel: K8sKind = {
   label: 'Cluster Operator',
   labelPlural: 'Cluster Operators',
   apiVersion: 'v1',
-  path: 'clusteroperators',
   apiGroup: 'config.openshift.io',
   plural: 'clusteroperators',
   abbr: 'CO',
@@ -870,7 +865,6 @@ export const ClusterVersionModel: K8sKind = {
   label: 'Cluster Version',
   labelPlural: 'Cluster Versions',
   apiVersion: 'v1',
-  path: 'clusterversions',
   apiGroup: 'config.openshift.io',
   plural: 'clusterversions',
   abbr: 'CV',
@@ -884,7 +878,6 @@ export const ClusterAutoscalerModel: K8sKind = {
   label: 'Cluster Autoscaler',
   labelPlural: 'Cluster Autoscalers',
   apiVersion: 'v1',
-  path: 'clusterautoscalers',
   apiGroup: 'autoscaling.openshift.io',
   plural: 'clusterautoscalers',
   abbr: 'CA',
@@ -899,7 +892,6 @@ export const OAuthModel: K8sKind = {
   label: 'OAuth',
   labelPlural: 'OAuths',
   apiVersion: 'v1',
-  path: 'oauths',
   apiGroup: 'config.openshift.io',
   plural: 'oauths',
   abbr: 'OA',
@@ -908,3 +900,68 @@ export const OAuthModel: K8sKind = {
   id: 'oauth',
   crd: true,
 };
+
+export const InfrastructureModel: K8sKind = {
+  label: 'Infrastructure',
+  labelPlural: 'Infrastructures',
+  apiVersion: 'v1',
+  apiGroup: 'config.openshift.io',
+  plural: 'infrastructures',
+  abbr: 'INF',
+  namespaced: false,
+  kind: 'Infrastructure',
+  id: 'infrastructure',
+  crd: true,
+};
+
+export const ConsoleLinkModel: K8sKind = {
+  label: 'Console Link',
+  labelPlural: 'Console Links',
+  apiVersion: 'v1',
+  apiGroup: 'console.openshift.io',
+  plural: 'consolelinks',
+  abbr: 'CL',
+  namespaced: false,
+  kind: 'ConsoleLink',
+  id: 'consolelink',
+  crd: true,
+};
+
+export const ConsoleCLIDownloadModel: K8sKind = {
+  label: 'Console CLI Download',
+  labelPlural: 'Console CLI Downloads',
+  apiVersion: 'v1',
+  apiGroup: 'console.openshift.io',
+  plural: 'consoleclidownloads',
+  abbr: 'CCD',
+  namespaced: false,
+  kind: 'ConsoleCLIDownload',
+  id: 'consoleclidownload',
+  crd: true,
+};
+
+export const ConsoleNotificationModel: K8sKind = {
+  label: 'Console Notification',
+  labelPlural: 'Console Notifications',
+  apiVersion: 'v1',
+  apiGroup: 'console.openshift.io',
+  plural: 'consolenotifications',
+  abbr: 'CN',
+  namespaced: false,
+  kind: 'ConsoleNotification',
+  id: 'consolenotification',
+  crd: true,
+};
+
+export const ConsoleExternalLogLinkModel: K8sKind = {
+  label: 'Console External Log Link',
+  labelPlural: 'Console External Log Links',
+  apiVersion: 'v1',
+  apiGroup: 'console.openshift.io',
+  plural: 'consoleexternalloglinks',
+  abbr: 'CELL',
+  namespaced: false,
+  kind: 'ConsoleExternalLogLink',
+  id: 'consoleexternalloglink',
+  crd: true,
+};
